TBF = 253   # Taxa Básica Financeira
TJLP = 256  # Taxa de juros - TJLP
TR = 226    # Taxa Referencial

SELIC = 11             # Taxa de juros - Selic
SELIC_ACUM_MES = 4390  # Taxa de juros - Selic acumulada no mês
SELIC_META = 432      # Taxa de juros - Meta Selic definida pelo Copom

CDI = 12  # Taxa de Juros - CDI

IGPDI = 190   # Índice geral de preços-disponibilidade interna (IGP-DI)
IGP10 = 7447  # Índice Geral de Preços-10 (IGP-10)
IPA = 7450    # Índice de Preços por Atacado-Mercado (IPA-M)
IPC = 191     # Índice de preços ao consumidor-Brasil (IPC-Br)
IPCA = 433    # Índice nacional de preços ao consumidor-amplo (IPCA)
INCC = 192    # Índice nacional de custo da construção (INCC)

OURO = 4  # Ouro BM&F - grama

BOVESPA_INDICE = 7              # Bovespa - índice
BOVESPA_VOLUME = 8              # Bovespa - Volume
BOVESPA_QTD_LISTADAS = 7850     # Quantidade de companhias listadas na Bovespa
BOVESPA_VALOR_LISTADAS = 7849	# Valor das empresas listadas na Bovespa
DOWN_JONES = 7809               # Dow Jones NYSE - índice
NASDAQ = 7810                   # Nasdaq - índice

PIB_RS_CORRENTE = 1207  # Produto interno bruto em R$ correntes
PIB_VAR_PERC = 7326     # Produto Interno Bruto - Tx. variação real no ano
POUPANCA_I = 25         # Depósitos poupança até 03.05.12 - Rentab. no período
POUPANCA_II = 195       # Depósitos poupança após 04.05.12 - Rentab. no período
